---
title: <span class="badge builder"></span> QueryEditorOperatorExpression
---
# <span class="badge builder"></span> QueryEditorOperatorExpression

## Constructor

```python
QueryEditorOperatorExpression()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> cloudwatch.QueryEditorOperatorExpression
```

### <span class="badge object-method"></span> operator

TS type is operator: QueryEditorOperator<QueryEditorOperatorValueType>, extended in veneer

```python
def operator(operator: cogbuilder.Builder[cloudwatch.QueryEditorOperator]) -> typing.Self
```

### <span class="badge object-method"></span> property_val

```python
def property_val(property_val: cogbuilder.Builder[cloudwatch.QueryEditorProperty]) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [QueryEditorOperatorExpression](./object-QueryEditorOperatorExpression.md)
